@@ -1,16 +1,15 @@
-from typing import Dict, Callable, IO
 import base64
 import gzip
 import io
 import tarfile
-from typing import Dict, Iterable, Callable
+from typing import IO, Callable, Dict, Iterable
 
+from ..exception import NotSupportedKernelType
 from .kernels import KERNEL_CREATEORS
 from .package import Package
-from .packaging_system import build_package
-from ..exception import NotSupportedKernelType
+from .packaging_system import build_packages, get_dependencies
 
-Builder = Callable[[IO[str], Dict], str]
+Builder = Callable[[IO[str], str, Dict], str]
 
 
 def create_encoded_archive(pkgs: Iterable[Package]) -> str:
@@ -25,18 +24,26 @@ def create_encoded_archive(pkgs: Iterable[Package]) -> str:
     return base64.b64encode(compressed).decode("utf-8")
 
 
-def get_builder(kernel_type: str, enable_internet: bool = False) -> Callable:
+def get_builder(kernel_type: str) -> Builder:
     if kernel_type not in KERNEL_CREATEORS:
         raise NotSupportedKernelType(kernel_type)
 
-    def _builder(kernel_body_io: IO[str], env_variables: Dict) -> str:
-        pkgs = build_package(not enable_internet)
-        encoded_archive = create_encoded_archive(pkgs)
+    def _builder(
+        kernel_body_io: IO[str],
+        pkg_dataset: str,
+        env_variables: Dict,
+        enable_internet: bool,
+        enable_constraint: bool,
+    ) -> str:
+        encoded_archive = create_encoded_archive(build_packages())
+        dependencies = get_dependencies(enable_constraint)
         kernel_body = kernel_body_io.read()
         return KERNEL_CREATEORS[kernel_type](
             kernel_body,
             pkg_encoded=encoded_archive,
+            pkg_dataset=pkg_dataset,
             env_variables=env_variables,
+            dependencies=dependencies,
             enable_internet=enable_internet,
         )
 
