@@ -1,5 +1,5 @@
-from typing import Dict
 import json
+from typing import Dict, Iterable
 
 from .bootstrap import create_bootstrap_code
 
@@ -13,11 +13,17 @@ def erace_all_outputs(notebook: Dict) -> Dict:
 
 
 def create_bootstrap_cell(
-    pkg_encoded: str, env_variables: Dict, enable_internet: bool = False
+    pkg_encoded: str,
+    pkg_dataset: str,
+    env_variables: Dict,
+    dependencies: Iterable[str],
+    enable_internet: bool = False,
 ) -> Dict:
     bootstrap_code = create_bootstrap_code(
         pkg_encoded=pkg_encoded,
+        pkg_dataset=pkg_dataset,
         env_variables=env_variables,
+        dependencies=dependencies,
         enable_internet=enable_internet,
     )
     return {
@@ -32,14 +38,18 @@ def create_bootstrap_cell(
 def create_notebook_kernel(
     notebook_body: str,
     pkg_encoded: str,
+    pkg_dataset: str,
     env_variables: Dict,
+    dependencies: Iterable[str],
     enable_internet: bool = False,
 ) -> str:
     notebook_obj = erace_all_outputs(json.loads(notebook_body))
 
     bootstrap_cell = create_bootstrap_cell(
         pkg_encoded=pkg_encoded,
+        pkg_dataset=pkg_dataset,
         env_variables=env_variables,
+        dependencies=dependencies,
         enable_internet=enable_internet,
     )
     notebook_obj.setdefault("cells", []).insert(0, bootstrap_cell)
